Covmatic RobotControl
=====================

This software is part of the Covmatic Project.

Python module to interface with a RobotManger instance.
This enables protocols written with Covmatic package to:
- ask a robot to pick up a plate from the deck
- ask a robot to drop off a plate on the deck

